Crate aqua_registry

Crate aqua_registry 

Aqua Registry

This crate provides functionality for working with Aqua package registry files. It handles parsing registry YAML, looking up packages, and managing compiled registry cache files. Fetching policy, remote fallback behavior, and baked-in registry integration live in mise.

Re-exports

pub use types::AquaChecksum;
pub use types::AquaChecksumType;
pub use types::AquaCosign;
pub use types::AquaFile;
pub use types::AquaGithubArtifactAttestations;
pub use types::AquaMinisign;
pub use types::AquaMinisignType;
pub use types::AquaPackage;
pub use types::AquaPackageType;
pub use types::AquaVar;
pub use types::RegistryYaml;

Modules

types

Structs

CompiledRegistry
ParsedRegistry
RegistryCache

Enums

AquaRegistryError
Errors that can occur when working with the Aqua registry

Functions

decode_package_rkyv
encode_package_rkyv

Type Aliases

Result